<?php

namespace Drupal\yandex_maps\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;

class YandexMapsSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'yandex_maps_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [
      'yandex_maps.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('yandex_maps.settings');

    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API key'),
      '#description' => $this->t('API key from @link', [
        '@link' => Link::fromTextAndUrl(
          'developer.tech.yandex.ru',
          Url::fromUri('https://developer.tech.yandex.ru/services', ['attributes' => ['target' => '_blank']])
        )->toString(),
      ]),
      '#default_value' => $config->get('api_key'),
    ];

    $form['presets_file_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Path to presets'),
      '#description' => $this->t('Path to Yandex Map presets. Example: <code>@example</code>', [
        '@example' => \Drupal::service('extension.list.module')->getPath('yandex_maps') . '/js/yandex-maps-presets.example.js',
      ]),
      '#default_value' => $config->get('presets_file_path'),
    ];

    $form['objects_default_preset'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Objects default preset'),
      '#description' => $this->t('Default <a href="@url" target="_blank">preset</a> name. Example: <code>islands#blueDotIcon</code>', [
        '@url' => 'https://yandex.ru/dev/jsapi-v2-1/doc/ru/v2-1/ref/reference/option.presetStorage',
      ]),
      '#default_value' => $config->get('objects_default_preset'),
    ];

    $form['debug_mode'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Debug mode'),
      '#description' => $this->t('Use unpacked version Yandex.Maps API script. Not recomend on production sites.'),
      '#default_value' => $config->get('debug_mode'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('yandex_maps.settings')
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('presets_file_path', $form_state->getValue('presets_file_path'))
      ->set('objects_default_preset', $form_state->getValue('objects_default_preset'))
      ->set('debug_mode', $form_state->getValue('debug_mode'))
      ->save();

    drupal_flush_all_caches();

    parent::submitForm($form, $form_state);
  }

}
